@@ -2,7 +2,7 @@ package WebService::Stripe;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.0700'; # VERSION
+our $VERSION = '0.0800'; # VERSION
 
 use Carp qw(croak);
 use Method::Signatures;
@@ -136,6 +136,18 @@ method cancel_transfer(Str $id, :$headers) {
     return $self->post("/v1/transfers/$id/cancel", undef, headers => $headers);
 }
 
+method get_bitcoin_receivers(HashRef :$query, :$headers) {
+    return $self->get( "/v1/bitcoin/receivers", $query, headers => $headers );
+}
+
+method create_bitcoin_receiver(HashRef $data, :$headers) {
+    return $self->post( "/v1/bitcoin/receivers", $data, headers => $headers );
+}
+
+method get_bitcoin_receiver(Str $id, :$headers) {
+    return $self->get( "/v1/bitcoin/receivers/$id", {}, headers => $headers );
+}
+
 # ABSTRACT: Stripe API bindings
 
 
@@ -153,7 +165,7 @@ WebService::Stripe - Stripe API bindings
 
 =head1 VERSION
 
-version 0.0700
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -358,6 +370,26 @@ Example:
 
     get_balance()
 
+=head2 get_bitcoin_receivers
+
+    get_bitcoin_receivers()
+
+=head2 create_bitcoin_receiver
+
+    create_bitcoin_receiver($data)
+
+Example:
+
+    my $receiver = $stripe->create_bitcoin_receiver({
+        amount   => 100,
+        currency => 'usd',
+        email    => 'bob@tilt.com',
+    });
+
+=head2 get_bitcoin_receiver
+
+    get_bitcoin_receiver($id)
+
 =head1 AUTHORS
 
 =over 4
